#!/bin/bash
# Nathan Oyama <nathan.oyama@ibm.com> - Wed Jan  9 03:52:23 STD 2019

set -e

if [ "$1" == "-h" ] || [ "$1" == "--help" ]; then
  echo -e "USAGE
-----
On IBM Spectrum Protect Plus, run the following command using the serveradmin
account:

$ sudo bash ./isoCompDuplicator.sh"
  exit 0
fi

TARGET_PATH="/opt/virgo/repository/ecx-usr" 
TEMP_PATH="/opt/virgo/repository/temp-properties"

# Ensure the script is run by root/sudo.
if [ "$EUID" -ne 0 ]; then
  echo "Permission denied. $(whoami), please use root or sudo. Aborting."    >&2
  exit 1
fi

if [ ! -d $TARGET_PATH ]; then
  echo "Could not find the directory \"$TARGET_PATH/\"."                     >&2
  echo "Could not retrieve the SPP version. Make sure you are running this " >&2
  echo "script on a valid IBM Spectrum Protect Plus appliance. Aborting."    >&2
  exit 1
fi

mkdir -p "$TEMP_PATH"
if [ ! -d $TEMP_PATH ]; then
  echo "Could not create a directory \"$TEMP_PATH/\". Aborting."             >&2
  exit 1
fi

TIMESTAMP="$(env TZ=UTC date +%F_%H%M)utc"
VERSION="$(rpm -qa --queryformat "%{VERSION}-%{RELEASE}\n" spp-release)"

if [ -z "$VERSION" ]; then
  echo "Could not retrieve the SPP version. Make sure you are running this " >&2
  echo "script on a valid IBM Spectrum Protect Plus appliance. Aborting."    >&2
  exit 1
fi

FILE_LIST="$TEMP_PATH/properties.$VERSION.$TIMESTAMP.dat"

if [ -e $FILE_LIST ]; then
  rm -e $FILE_LIST
fi
touch $FILE_LIST
if [ ! -e $FILE_LIST ]; then
  echo "Could not create a file \"$FILE_LIST\". Aborting."                   >&2
  exit 1
fi

ls $TARGET_PATH/*.properties | while read originFile; do
  backup_file="$TEMP_PATH/$(basename $originFile).$VERSION.$TIMESTAMP"
  cp $originFile $backup_file && echo "$backup_file" >> $FILE_LIST
  if ! $(cmp --silent $originFile $backup_file); then
    echo "Unable to copy $originFile . Aborting."                            >&2
    rm -fv $FILE_LIST                                                        >&2
    rm -fv $TEMP_PATH/*.$VERSION.$TIMESTAMP                                  >&2
    exit 1
  fi
done

echo "Duplication operation has been done successfully."
echo -e "\n$FILE_LIST\n"
cat $FILE_LIST

exit $?

