#!/bin/bash
# Nathan Oyama <nathan.oyama@ibm.com> - Sat Jan  5 06:57:57 STD 2019
set -e

SCRIPT_DIR=$(dirname "$(test -L "$0" && readlink "$0" || echo "$0")")
TARGET_PATH="/opt/virgo/repository/ecx-usr" 
TEMP_PATH="/opt/virgo/repository/temp-properties"

# Ensure the script is run by root/sudo.
if [ "$EUID" -ne 0 ]; then
  echo "Permission denied. $(whoami), please use root or sudo. Aborting."    >&2
  exit 1
fi

# Log
if [ -w /data/log/adminconsole/ ]; then
  LOGFILE="/data/log/adminconsole/properties-update.log"
else
  LOGFILE="/tmp/properties-update.log"
fi
env TZ=UTC date                                                  >> $LOGFILE
echo "$0 $@"                                                     >> $LOGFILE

# Set flag vars to empty.
HELP= QUIET=

while getopts :f:qh opt; do
  case $opt in
    h)  HELP=true
      ;;
    q)  QUIET=true
      ;;
    '?') echo "$0: invalid option -$OPTARG. Try $0 -h . Aborting."           >&2
      exit 1
      ;;
  esac
done
shift $((OPTIND - 1))

if [ $QUIET ]; then
  2>/dev/null 1>/dev/null bash $0
  exit $?
fi

if [ $HELP ]; then
  echo "Usage: sudo bash ./isoprep_pre.sh [OPTION]"
  echo "  Use this command before installing an update ISO file into IBM"
  echo "  Spectrum Protect Plus. This script will createe a backup of"
  echo "  all the properties files in $TARGET_PATH and store them in" 
  echo "  $TEMP_PATH ."
  echo "Options:"
  echo "  -q : Suppress all normal output."
  echo "  -h : Show this help."
  exit 0
fi

bash ${SCRIPT_DIR}/isoCompDuplicator.sh                    | tee -a $LOGFILE

exit $?

