#!/bin/bash

LOG="/data/log/adminconsole/prerequisite_check.log"

# Ugly here should be refactored to something better. Meant to work around
# the strange threading/buffering adminconsole java behavior when shell
# scripts are used
output () {
	echo $*
	echo $* >> $LOG
}

fail_upgrade () {
	output "==> The upgrade failed the prerequisite safety check. Please"
	output "==> see the output checks performed above for corrective"
	output "==> action.  Prior to re-trying the upgrade, please reboot"
	output "==> the appliance to clear out cached data"

	output "..."
	output "..."
	sleep 180
	echo
	echo

	exit 1
}

# If customer doesn't want to deal with the space issue, then create a file /tmp/space_bypass
# look for /tmp/space_bypass
# touch /tmp/space_bypass

output "==> Running prerequisite tests"
d=$(date)
output "$d"

output "==> Space available in key directories"
# ugly, multi-line output doesn't work well with the dual output
df -k / /var /tmp
df -k / /var /tmp >> $LOG

if [ -e /tmp/space_bypass ] ; then
        output "=> space_bypass file detected. Deleting it and proceeding."
        rm /tmp/space_bypass
        exit 0
fi

output "==> Checking for minimum space requirements in /, /var and /tmp"

SPACE_AVAILABLE_ROOT=$(df -k / | tail -1 | awk '{print $4}')
MIN_SPACE_REQUIRED_ROOT=2000000
SPACE_AVAILABLE_VAR=$(df -k /var | tail -1 | awk '{print $4}')
MIN_SPACE_REQUIRED_VAR=1500000
SPACE_AVAILABLE_TMP=$(df -k /tmp | tail -1 | awk '{print $4}')
MIN_SPACE_REQUIRED_TMP=500000

if [ $SPACE_AVAILABLE_ROOT -lt $MIN_SPACE_REQUIRED_ROOT ] ; then
	output "Fail: Minimum space required for upgrade in the / directory is $MIN_SPACE_REQUIRED_ROOT"
	output "The space currently available is $SPACE_AVAILABLE_ROOT"
	fail_upgrade
fi

if [ $SPACE_AVAILABLE_VAR -lt $MIN_SPACE_REQUIRED_VAR ] ; then
        output "Fail: Minimum space required for upgrade in the /var directory is $MIN_SPACE_REQUIRED_VAR"
        output "The space currently available is $SPACE_AVAILABLE_VAR"
        fail_upgrade
fi

if [ $SPACE_AVAILABLE_TMP -lt $MIN_SPACE_REQUIRED_TMP ] ; then
        output "Fail: Minimum space required for upgrade in the / directory is $MIN_SPACE_REQUIRED_TMP"
        output "The space currently available is $SPACE_AVAILABLE_TMP"
        fail_upgrade
fi

output "==> Checking postgres login"
pg=$(fgrep postgres /etc/passwd)
output "$pg"

su - postgres -c true
if [ $? -ne 0 ] ; then
 	output "Fail: Postgres account is locked. To continue with the upgrade, make sure it is unlocked."
 	fail_upgrade
fi

# Disabling CBC ciphers from the sshd_config.
# We check if CBC ciphers are disabled. If not, then a backup of the file is made and the required
# changes are performed.
isCipherListEnabled=$(cat /etc/ssh/sshd_config | grep -c "Ciphers chacha20-poly1305@openssh.com,aes128-ctr,aes192-ctr,aes256-ctr,aes128-gcm@openssh.com,aes256-gcm@openssh.com")

if [ $isCipherListEnabled -eq 0 ]; then
   echo "Creating backup of sshd_config"
   cp -uv /etc/ssh/sshd_config /etc/ssh/sshd_config.bak
   
   echo "Adding Cipher list to the config. This makes sure that CBC ciphers are disabled in the SSH Daemon configuration."
   echo "Cipher list includes: Ciphers chacha20-poly1305@openssh.com,aes128-ctr,aes192-ctr,aes256-ctr,aes128-gcm@openssh.com,aes256-gcm@openssh.com"
   echo "Ciphers chacha20-poly1305@openssh.com,aes128-ctr,aes192-ctr,aes256-ctr,aes128-gcm@openssh.com,aes256-gcm@openssh.com" >> /etc/ssh/sshd_config
   echo "Restarting sshd service"
   systemctl restart sshd.service
else 
   echo "No configuration changes required to the sshd_config file."
fi
